package com.yiqi.recharge.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.recharge.domain.RechargeCardVersion;

/**
 * 充值卡版本Mapper接口
 *
 * @author 小黑
 * @date 2023-08-29
 */
@Mapper
public interface RechargeCardVersionMapper extends BaseMapper<RechargeCardVersion> {
    /**
     * 查询充值卡版本
     *
     * @param id 充值卡版本主键
     * @return 充值卡版本
     */
    public RechargeCardVersion selectRechargeCardVersionById(Long id);

    /**
     * 查询充值卡版本列表
     *
     * @param rechargeCardVersion 充值卡版本
     * @return 充值卡版本集合
     */
    public List<RechargeCardVersion> selectRechargeCardVersionList(RechargeCardVersion rechargeCardVersion);

    /**
     * 新增充值卡版本
     *
     * @param rechargeCardVersion 充值卡版本
     * @return 结果
     */
    public int insertRechargeCardVersion(RechargeCardVersion rechargeCardVersion);

    /**
     * 修改充值卡版本
     *
     * @param rechargeCardVersion 充值卡版本
     * @return 结果
     */
    public int updateRechargeCardVersion(RechargeCardVersion rechargeCardVersion);

    /**
     * 删除充值卡版本
     *
     * @param id 充值卡版本主键
     * @return 结果
     */
    public int deleteRechargeCardVersionById(Long id);

    /**
     * 批量删除充值卡版本
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRechargeCardVersionByIds(Long[] ids);
}
